edf: Read data stored in a European Data Format (EDF and EDF+)...

edfR Documentation

Read data stored in a European Data Format (EDF and EDF+) file.

Description

The edf package provides methods for reading files containing physiologic data stored in a European Data Format (EDF and EDF+) file and returns the data as a structured list.

Author(s)

Maintainer: Andreas Henelius andreas.henelius@iki.fi

Authors:

Other contributors:

  • Finnish Institute of Occupational Health [copyright holder]

References

Kemp B., Värri, A., Rosa, A.C., Nielsen, K.D. and Gade, J. (1992). A simple format for exchange of digitized polygraphic recordings. Electroencephalogr Clin Neurophysiol. 1992 May;82(5):391-3. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/0013-4694(92)90009-7")}

Kemp, B. and Olivan, J. (2003). European data format 'plus' (EDF+), an EDF alike standard format for the exchange of physiological data. Clin Neurophysiol. 2003 Sep;114(9):1755-61. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/s1388-2457(03)00123-8")}

See Also

Useful links:


edf documentation built on Aug. 31, 2026, 5:08 p.m.

Related to edf in edf...