edf.char.to.num: Convert string to a numeric.

View source: R/utilities.R

edf.char.to.numR Documentation

Convert string to a numeric.

Description

This function removes spaces from a string and converts it to a numeric. This is required when reading EDF data, since the data fields in the header are of fixed size, and extra whitespace must hence be trimmed.

Usage

edf.char.to.num(s)

Arguments

s

The string to be converted

Value

A numeric.

Examples

s <- "123   "
edf:::edf.char.to.num(s)

edf documentation built on Aug. 31, 2026, 5:08 p.m.

Related to edf.char.to.num in edf...