parse.edf.global.header: #' Parse the global header of a European Data Format (EDF and...

View source: R/utilities.R

parse.edf.global.headerR Documentation

#' Parse the global header of a European Data Format (EDF and EDF+) file.

Description

This function parses the header of an EDF or EDF+ file.

Usage

parse.edf.global.header(data)

Arguments

data

The 256 bytes of raw data that contain the EDF/EDF+ header.

Value

A named list containing the information in the EDF/EDF+ header.


edf documentation built on Aug. 31, 2026, 5:08 p.m.