parse.edf.signal.header: Parse the signal header of a European Data Format (EDF and...

View source: R/utilities.R

parse.edf.signal.headerR Documentation

Parse the signal header of a European Data Format (EDF and EDF+) file.

Description

This function parses the signal header of an EDF or EDF+ file.

Usage

parse.edf.signal.header(data, header.global)

Arguments

data

The n*256 bytes of raw data that contain the EDF/EDF+ signal header,

header.global

The global EDF/EDF+ header. #' where n is the number of signals in the EDF/EDF+ file.

Value

A named list containing the information in the EDF/EDF+ signal header.


edf documentation built on Aug. 31, 2026, 5:08 p.m.