parse.event: Parse one EDF+ Time-stamped Annotation List (TAL).

View source: R/utilities.R

parse.eventR Documentation

Parse one EDF+ Time-stamped Annotation List (TAL).

Description

This function parses one EDF+ Time-stamped Annotation List (TAL).

Usage

parse.event(data)

Arguments

data

The bytes of raw data that contain the TAL.

Value

A data frame containing the information in the TAL: onset, duration and annotation.


edf documentation built on Aug. 31, 2026, 5:08 p.m.

Related to parse.event in edf...