This function reads the data stored in an EDF or EDF+ file. This data consists of, e.g., physiologic signals and possibly also annotations (EDF+ files only).
read.edf(filename, read.annotations = TRUE, header.only = FALSE)The full path to the EDF/EDF+ file to be read.
Boolean denoting whether or not annotations should be read, if they are present. Defaults is TRUE.
Boolean denoting whether to only read the headers in the EDF file. Default is FALSE. #' @return A list containing
the global header (recording start date, duration etc).
the signal headers (transducer types, sampling rates etc).
the signal data
the events (annotations). This is always NA for EDF files. This is NA for EDF+ files without annotations.
Kemp B., Värri, A., Rosa, A.C., Nielsen, K.D. and Gade, J. (1992). A simple format for exchange of digitized polygraphic recordings. Electroencephalogr Clin Neurophysiol. 1992 May;82(5):391-3. tools:::Rd_expr_doi("10.1016/0013-4694(92)90009-7")
Kemp, B. and Olivan, J. (2003). European data format 'plus' (EDF+), an EDF alike standard format for the exchange of physiological data. Clin Neurophysiol. 2003 Sep;114(9):1755-61. tools:::Rd_expr_doi("10.1016/s1388-2457(03)00123-8")