trim.end: Remove trailing whitespace from a string.

View source: R/utilities.R

trim.endR Documentation

Remove trailing whitespace from a string.

Description

This function removes trailing whitespace from a string. This is required when reading EDF data, since the data fields in the header are of fixed size, and extra whitespace must hence be trimmed.

Usage

trim.end(s)

Arguments

s

The string to be converted

Value

The string gives as input without trailing whitespace

Examples

s <- "abc   "
edf:::trim.end(s)

edf documentation built on Aug. 31, 2026, 5:08 p.m.

Related to trim.end in edf...