| edf | R Documentation |
The edf package provides methods for reading files containing physiologic data stored in a European Data Format (EDF and EDF+) file and returns the data as a structured list.
Maintainer: Andreas Henelius andreas.henelius@iki.fi
Authors:
Andreas Henelius andreas.henelius@iki.fi
Other contributors:
Finnish Institute of Occupational Health [copyright holder]
Kemp B., Värri, A., Rosa, A.C., Nielsen, K.D. and Gade, J. (1992). A simple format for exchange of digitized polygraphic recordings. Electroencephalogr Clin Neurophysiol. 1992 May;82(5):391-3. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/0013-4694(92)90009-7")}
Kemp, B. and Olivan, J. (2003). European data format 'plus' (EDF+), an EDF alike standard format for the exchange of physiological data. Clin Neurophysiol. 2003 Sep;114(9):1755-61. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/s1388-2457(03)00123-8")}
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.