| edf.char.to.num | R Documentation |
This function removes spaces from a string and converts it to a numeric. This is required when reading EDF data, since the data fields in the header are of fixed size, and extra whitespace must hence be trimmed.
edf.char.to.num(s)
s |
The string to be converted |
A numeric.
s <- "123 "
edf:::edf.char.to.num(s)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.