Learn R Programming

edf (version 1.0.1)

edf.char.to.num: Convert string to a numeric.

Description

This function removes spaces from a string and converts it to a numeric. This is required when reading EDF data, since the data fields in the header are of fixed size, and extra whitespace must hence be trimmed.

Usage

edf.char.to.num(s)

Value

A numeric.

Arguments

s

The string to be converted

Examples

Run this code
s <- "123   "
edf:::edf.char.to.num(s)

Run the code above in your browser using DataLab