powered by
This function removes spaces from a string and converts it to a numeric. This is required when reading EDF data, since the data fields in the header are of fixed size, and extra whitespace must hence be trimmed.
edf.char.to.num(s)
A numeric.
The string to be converted
s <- "123 " edf:::edf.char.to.num(s)
Run the code above in your browser using DataLab