parse.edf.global.header: #' Parse the global header of a European Data Format (EDF and EDF+) file.
Description
This function parses the header of an EDF or EDF+ file.
Usage
parse.edf.global.header(data)
Value
A named list containing the information in the EDF/EDF+ header.
Arguments
- data
The 256 bytes of raw data that contain the EDF/EDF+ header.