Learn R Programming

edf (version 1.0.1)

parse.event: Parse one EDF+ Time-stamped Annotation List (TAL).

Description

This function parses one EDF+ Time-stamped Annotation List (TAL).

Usage

parse.event(data)

Value

A data frame containing the information in the TAL: onset, duration and annotation.

Arguments

data

The bytes of raw data that contain the TAL.