powered by
This function parses one EDF+ Time-stamped Annotation List (TAL).
parse.event(data)
A data frame containing the information in the TAL: onset, duration and annotation.
The bytes of raw data that contain the TAL.