| trim.end | R Documentation |
This function removes trailing whitespace from a string. This is required when reading EDF data, since the data fields in the header are of fixed size, and extra whitespace must hence be trimmed.
trim.end(s)
s |
The string to be converted |
The string gives as input without trailing whitespace
s <- "abc "
edf:::trim.end(s)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.