Learn R Programming

edf (version 1.0.1)

trim.end: Remove trailing whitespace from a string.

Description

This function removes trailing whitespace from a string. This is required when reading EDF data, since the data fields in the header are of fixed size, and extra whitespace must hence be trimmed.

Usage

trim.end(s)

Value

The string gives as input without trailing whitespace

Arguments

s

The string to be converted

Examples

Run this code
s <- "abc   "
edf:::trim.end(s)

Run the code above in your browser using DataLab