trim.end: Remove trailing whitespace from a string.
Description
This function removes trailing whitespace from a string.
This is required when reading EDF data, since the data fields in the header
are of fixed size, and extra whitespace must hence be trimmed.
Usage
trim.end(s)
Value
The string gives as input without trailing whitespace